import sys
from focus.day import focus_day


def day(args=None):
    """The main routine."""
    if args is None:
        args = sys.argv[1:]

    focus_day()

if __name__ == "__main__":
    sys.exit(day())


import numpy as np
from focus.timer_backend import timer

def focus_session():
    '''      FOCUS TIMER for one session     '''
    target_focus_duration =         float(input('How long would you like to focus for? (minutes)          '))

    # set the maximum session duration given the target focus time
    if target_focus_duration <= 5: maximum_session_duration = 10.
    elif target_focus_duration <= 15: maximum_session_duration = target_focus_duration * 2
    elif target_focus_duration < 20: maximum_session_duration = 30.
    else: maximum_session_duration = target_focus_duration * 1.5 

    # set the average, minimum and maximum interval between focus reminders (the ding-dong sound)
    if target_focus_duration > 2: average_interval = np.sqrt(target_focus_duration) * 60
    else: average_interval = target_focus_duration / 2 * 60
    minimum_interval = min(20, average_interval/2)
    maximum_interval = average_interval*2

    # Run the session
    time_focused_session = timer(target_focus_duration, maximum_session_duration, average_interval, minimum_interval, maximum_interval)
    return time_focused_session

if __name__ == "__main__":
    focus_session()


import numpy as np
import time
from playsound import playsound
import msvcrt
from datetime import datetime
from pathlib import Path

def focus_query(caption, timeout = 5):
    start_time = time.time()
    while msvcrt.kbhit(): msvcrt.getche() # Remove keys pressed in the interval
    print(caption);
    playsound(str(Path(__file__).parent / '../data/ding dong.mp3'))
    while True: # If a key is pressed, return False; otherwise True
        if msvcrt.kbhit(): return False
        if (time.time() - start_time) > timeout: return True


def timer(target_focus_duration, maximum_session_duration, average_interval, minimum_interval, maximum_interval):  
    print(datetime.now())
    print('\nstarting focus session for {} to {} minutes\n'.format(target_focus_duration, maximum_session_duration))
    playsound(str(Path(__file__).parent / '../data/start.mp3'))
    # how much time is left
    focus_time_left = target_focus_duration*60
    # set a timer for the whole session
    session_start_time = time.time()
    minute_timer_start_time = time.time()
    failed = False
    # Start the main loop
    while focus_time_left > 0:
        # Select the interval between reminders (ding dong sound)
        interval = -1
        while interval < minimum_interval or interval > maximum_interval:
            interval = np.random.exponential(scale = (average_interval - minimum_interval)) + minimum_interval
        # Wait for the interval to pass
        interval_start_time = time.time()
        interval_time_elapsed = 0
        while interval_time_elapsed < interval:
            minute_timer_time_elapsed = time.time() - minute_timer_start_time
            interval_time_elapsed = time.time() - interval_start_time
            total_time_elapsed = time.time() - session_start_time
            if int(minute_timer_time_elapsed) > 0 and int(minute_timer_time_elapsed) % 60 == 0: 
                minute_timer_start_time = time.time()
                print('')
            if total_time_elapsed > maximum_session_duration*60:
                print('Out of time.')
                playsound(str(Path(__file__).parent / '../data/failure.mp3'))
                failed = True
                break

        if failed:
            break
        else:  
            ans = focus_query('Were you focusing? If yes, carry on. If no, press any key within 10 seconds', timeout = 10) 
            if ans:
                print('\nGreat job!')
                focus_time_left -= (interval+10)
                print(str(np.round(100-100*focus_time_left / (target_focus_duration*60))) + '% done\n')
            else:
                print('Keep at it, champ\n')
    if not failed:
        print('You did it!!!')
        playsound(str(Path(__file__).parent / '../data/success.mp3'))

    time_focused_session = (target_focus_duration - (focus_time_left/60))
    return time_focused_session
    



import sys
from focus.session import focus_session


def session(args=None):
    """The main routine."""
    if args is None:
        args = sys.argv[1:]

    focus_session()

if __name__ == "__main__":
    sys.exit(session())


from focus.session import focus_session
from playsound import playsound
from pathlib import Path
import numpy as np

def focus_day():
    '''      FOCUS TIMER for multiple sessions over one day      '''
    target_focus_duration =         float(input('How long would you like to focus for today? (hours)          '))

    session_number = 1
    time_focused_day = 0

    while time_focused_day < target_focus_duration:
        time_left = target_focus_duration - time_focused_day
        if time_left < 1:
            print("\nYou have {} minutes to go. When you're ready let's start session number {}!\n".format(np.round(time_left*60,1), session_number))
        else:
            print("\nYou have {} hours to go. When you're ready let's start session number {}!\n".format(np.round(time_left,1), session_number))
        time_focused_session = focus_session() # run the focus session
        time_focused_day += (time_focused_session/60)
        session_number += 1
    
    print('\nCongratulations slugger, you have just scored a day of focus!')
    random_number = np.random.random()
    if random_number < .95:
        playsound(str(Path(__file__).parent / '../data/home run.mp3'))
    else: # once every twenty days, play this instead
        playsound(str(Path(__file__).parent / '../data/yay.mp3'))

if __name__ == "__main__":
    focus_day()


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="focus-time",
    version="1.0.5",
    author="Philip Shamash",
    author_email="philip.shamash.17@ucl.ac.uk",
    description="Focus time is an application in python to help you focus for a set amount of time",
    license = "GNU General Public License",
    url = "https://github.com/philshams/focus-time",
    packages=["focus"],
    package_dir={'focus':'focus'},
    package_data={'focus': ['../data/*.mp3']},
    install_requires=['DateTime>=4.3',
                      'numpy>=1.20.2',
                      'playsound>=1.2.2'                
                      ],
    entry_points={
        "console_scripts": [
            "focus = focus.__session__:session",
            "focus-time = focus.__session__:session",
            "focus-session = focus.__session__:session",
            "focus-day = focus.__day__:day"
        ]
    }
)